@@ -24,7 +24,7 @@ from .engine_intf import GenericStreamWrapper, BytesIOWrapper
 from .proto_handlers import load_protocol_handler
 from .utils.connect import connect_to_database, dataframe_to_sql
 from .utils.dbconn import sql_enquote_id
-from .utils.file_utils import write_stream_with_read_on_close, connect_to_filesystem
+from .utils.file_utils import write_stream_with_read_on_close, connect_to_filesystem, adapt_fsspec_storage_options
 from .utils.format_sniffer import find_url_extension, detect_format
 from .utils.nosql import connect_to_nosql
 from .utils.packages import install_packages
@@ -949,6 +949,8 @@ class DSLibrary(object):
         # various formats and their read function
         if use_dask:
             use_dask = format in DASK_READ_FORMATS
+            # FIXME 'filesystem', 'run_data' - dask won't open from a stream, so these are not implemented
+            #  - raise an exception
             read_method = DASK_READ_FORMATS.get(format, PANDAS_READ_FORMATS.get(format))
             if format == "csv" and use_dask:
                 # dask reads 'sample' bytes to determine dtypes, default is 256k, which is often too small
@@ -963,11 +965,11 @@ class DSLibrary(object):
             read_method = PANDAS_READ_FORMATS.get(format)
         if read_method:
             if use_dask:
-                storage_options = open_args.get("storage_options") or open_args
+                open_args = adapt_fsspec_storage_options(open_args)
                 try:
-                    return read_method(uri, storage_options=storage_options, **read_args)
+                    return read_method(uri, **open_args, **read_args)
                 except IsADirectoryError:
-                    return read_method(uri + "/*", storage_options=storage_options, **read_args)
+                    return read_method(uri + "/*", **open_args, **read_args)
             # when returning a chunk stream we need to keep the stream open until iteration completes
             if format_info.read_args.get("chunksize"):
                 class CloseAfterIteration(object):
