@@ -1,6 +1,7 @@
 import unittest
+import pandas
 
-from dslibrary.utils.connect import _process_params
+from dslibrary.utils.connect import _process_params, dataframe_to_sql
 
 
 class TestConnect(unittest.TestCase):
@@ -39,4 +40,11 @@ class TestConnect(unittest.TestCase):
             'password': ''
         }, r
 
-
+    def test_dataframe_to_sql(self):
+        df = pandas.DataFrame({"x": [1, 2, 3], "y": [1.0, 2.0, 4.0], "z": ["one", "two", "three"]})
+        sqls = list(dataframe_to_sql(df, "t1"))
+        self.assertEqual(sqls, [
+            ('DROP TABLE IF EXISTS t1', []),
+            ('CREATE TABLE IF NOT EXISTS t1 (x INTEGER, y DOUBLE, z VARCHAR(8))', []),
+            ('INSERT INTO t1 (x, y, z) VALUES (%s, %s, %s), (%s, %s, %s), (%s, %s, %s)', [1, 1.0, 'one', 2, 2.0, 'two', 3, 4.0, 'three'])
+        ])
